Enum ActivityBackoff

pub enum ActivityBackoff {
    Explicit(Vec<Duration>),
    Exponential {
        initial_interval: Duration,
        coefficient: u32,
        maximum_interval: Option<Duration>,
    },
}
Backoff intervals for one durable activity retry policy.

Variants



Explicit(Vec<Duration>)

Use these intervals between attempts. The server repeats the final interval if the retry budget contains more attempts than entries.



Exponential

Generate one interval for every retry using integer exponential growth.

Fields

initial_interval: Duration
coefficient: u32
maximum_interval: Option<Duration>