pub struct CancellationDelivery {
pub request_id: String,
pub sequence: u64,
pub call_kind: CancellationCallKind,
pub sequence_span: u64,
pub operation_sequence: Option<u64>,
pub operation_sequence_span: u64,
}Expand description
One committed delivery marker, bound to the original cancellation request.
Fields
request_id: Stringsequence: u64call_kind: CancellationCallKindsequence_span: u64operation_sequence: Option<u64>operation_sequence_span: u64Implementations
Sourceimpl CancellationDelivery
impl CancellationDelivery
Sourcepub fn interrupts(&self, sequence: u64) -> bool
pub fn interrupts(&self, sequence: u64) -> bool
Whether a sequence belongs to the canonical interrupted operation range.