pub struct CancellationScopeOpenReceipt { /* private fields */ }Expand description
A scope opening proved against complete history on its original claim. This proof does not advertise scoped workflow execution support.
Implementations