pub struct CooperativeCancellationRequested {
pub request: CancellationRequest,
pub delivery: CancellationDelivery,
}Expand description
Cancellation delivered at its committed authored call, with original identity.
Fields
request: CancellationRequestdelivery: CancellationDeliveryTrait Implementations
Sourceimpl Clone for CooperativeCancellationRequested
impl Clone for CooperativeCancellationRequested
Sourcefn clone(&self) -> CooperativeCancellationRequested
fn clone(&self) -> CooperativeCancellationRequested
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Error for CooperativeCancellationRequested
impl Error for CooperativeCancellationRequested
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
Sourceimpl PartialEq for CooperativeCancellationRequested
impl PartialEq for CooperativeCancellationRequested
Sourcefn eq(&self, other: &CooperativeCancellationRequested) -> bool
fn eq(&self, other: &CooperativeCancellationRequested) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CooperativeCancellationRequested
impl StructuralPartialEq for CooperativeCancellationRequested