pub struct ScopedCancellationContext { /* private fields */ }Expand description
Original scope ancestry carried by a candidate cooperative child request. Reading this immutable metadata does not authorize entering a scope body.
Implementations
Sourceimpl ScopedCancellationContext
impl ScopedCancellationContext
pub fn from_value(value: &Value) -> Result<Self>
pub fn root_context(&self) -> &CancellationContext
pub fn lineage(&self) -> &[ScopedCancellationLineage]
pub fn request_id(&self) -> &str
pub fn parent_request_id(&self) -> Option<&str>
pub fn workflow_instance_id(&self) -> &str
pub fn workflow_run_id(&self) -> &str
pub fn scope_id(&self) -> &str
pub fn root_scope_id(&self) -> &str
pub fn requested_at(&self) -> DateTime<Utc>
pub fn root_deadline(&self) -> DateTime<Utc>
pub fn deadline(&self) -> DateTime<Utc>
pub fn to_value(&self) -> Value