pub struct WorkerSessionOptions { /* private fields */ }Expand description
Routing and lifetime options for one worker-held session.
A holder replacement must rebuild its local resources. TTL expiry and explicit close are terminal for the session identity, even when lease reacquisition is enabled. Options do not create a session until sent to Server.
Implementations
Sourceimpl WorkerSessionOptions
impl WorkerSessionOptions
pub fn new(session_id: impl Into<String>) -> Self
pub fn session_id(&self) -> &str
pub fn task_queue(&self) -> Option<&str>
pub fn lease_duration(&self) -> Duration
pub fn ttl_duration(&self) -> Duration
pub fn connection(self, connection: impl Into<String>) -> Self
pub fn queue(self, queue: impl Into<String>) -> Self
pub fn requirements<I, S>(self, requirements: I) -> Self
pub fn lease_seconds(self, seconds: u64) -> Self
pub fn ttl_seconds(self, seconds: u64) -> Self
pub fn max_concurrent_activities(self, count: usize) -> Self
pub fn create_if_missing(self, enabled: bool) -> Self
pub fn allow_reacquire_after_failure(self, enabled: bool) -> Self
pub fn to_wire(&self) -> Result<Value>